<?php 
/*
　* @$Id
　* @
　* @Ver: 2.0
　* @Create: 2009-11-18 8:10
　* @Modify: 
　* @Author: CPWEB http://www.cpweb.net.cn
　* @Copyright (C) 2008 www.cpweb.net.cn. All Rights Reserved.
　* @License CPWEB is free software and use is subject to license terms
　*/
class DesignersAction extends GlobalAction 
{
	function _initialize(){
		parent::_initialize();
		$this->cpweb_model='module';
	}
	public function index()
	{
		$this->cpweb_list();
		$this->cpweb_display('Designers:index');
	}
	public function read(){
		$this->cpweb_read();
		$this->cpweb_find();
		$this->channel['id']=false;
		$this->cpweb_model='model';
		$this->cpweb_find['view']='View';
		$this->model='Cases';
		$this->cpweb_find['map']['Cases.designers_id']=intval($_REQUEST["id"]);
		//$this->cpweb_find['assign']['open']=true;
		$css=$this->cpweb_list();
		$this->cpweb_display('Designers:read');
	}
}
?>